==> barriosquare_0.2.2-1.tar.gz: barriosquare-0.2.2/barrioStyles.py <==
# This file is part of barrioSquare.
#
# barrioSquare is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# barrioSquare is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with barrioSquare. If not, see <http://www.gnu.org/licenses/>.
# or write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

QPUSHBUTTON_DEFAULT = 'QPushButton { color: #000000; border-radius: 6px; border: 2px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #f6f7fa, stop: 1 #dadbde); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #7ec2cc, stop: 1 #defbff); }'
QPUSHBUTTON_NOBORDER = 'QPushButton { color: #000000; border-radius: 0px; border: 0px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #f6f7fa, stop: 1 #dadbde); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #7ec2cc, stop: 1 #defbff); }'
QPUSHBUTTON_BLUE = 'QPushButton { color: #ffffff; border-radius: 6px; border: 2px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #157abd, stop: 1 #0d4a73); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #1b88d1, stop: 1 #115e91); }'
QPUSHBUTTON_HIGHLIGHT = 'QPushButton { color: #000000; border-radius: 6px; border: 2px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #7ec2cc, stop: 1 #defbff); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #cccccc, stop: 1 #f6f7fa); }'
QLISTWIDGET_DEFAULT = 'QListWidget { color: #000000; background-color: #ffffff; } QListView { color: #000000; background-color: #ffffff; }'
# '
QPUSHBUTTON_THIN_BORDER = 'QPushButton { color: #ffffff; border-radius: 4px; border: 1px solid #ed6d18; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #3d3838, stop: 1 #000000); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #ed6d18, stop: 1 #ff8a0d); }'

==> barriosquare_0.3.3-1.tar.gz: barriosquare-0.3.3/barrioStyles.py <==
# This file is part of barrioSquare.
#
# barrioSquare is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# barrioSquare is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with barrioSquare. If not, see <http://www.gnu.org/licenses/>.
# or write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

QPUSHBUTTON_DEFAULT = 'QPushButton { color: #000000; border-radius: 6px; border: 2px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #f6f7fa, stop: 1 #dadbde); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #7ec2cc, stop: 1 #defbff); }'
QPUSHBUTTON_NOBORDER = 'QPushButton { color: #000000; border-radius: 0px; border: 0px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #f6f7fa, stop: 1 #dadbde); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #7ec2cc, stop: 1 #defbff); }'
QPUSHBUTTON_NOBORDER_BLACK = 'QPushButton { color: #000000; border-radius: 0px; border: 0px solid #8f8f91; background-color: #000000; } QPushButton:pressed {background-color: #000000; }'
QPUSHBUTTON_BLUE = 'QPushButton { color: #ffffff; border-radius: 6px; border: 2px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #157abd, stop: 1 #0d4a73); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #1b88d1, stop: 1 #115e91); }'
QPUSHBUTTON_HIGHLIGHT = 'QPushButton { color: #000000; border-radius: 6px; border: 2px solid #8f8f91; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #7ec2cc, stop: 1 #defbff); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #cccccc, stop: 1 #f6f7fa); }'
QLISTWIDGET_DEFAULT = 'QListWidget { color: #000000; background-color: #ffffff; } QListView { color: #000000; background-color: #ffffff; }'
# '
QPUSHBUTTON_THIN_BORDER = 'QPushButton { color: #ffffff; border-radius: 4px; border: 1px solid #ed6d18; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #3d3838, stop: 1 #000000); } QPushButton:pressed {background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #ed6d18, stop: 1 #ff8a0d); }'
